@@ -1,4 +1,4 @@
-import os
+from pathlib import Path
 
 from credsweeper.app import CredSweeper
 from credsweeper.common.constants import ThresholdPreset
@@ -8,8 +8,6 @@ from credsweeper.file_handler import ContentProvider, ByteContentProvider, DiffC
 from credsweeper.ml_model.ml_validator import MlValidator
 from credsweeper.validations.apply_validation import ApplyValidation
 
-os.environ["TF_CPP_MIN_LOG_LEVEL"] = "2"
-
 __all__ = [
     'ApplyValidation',  #
     'ByteContentProvider',  #
@@ -21,7 +19,10 @@ __all__ = [
     'StringContentProvider',  #
     'TextContentProvider',  #
     'ThresholdPreset',  #
+    'CREDSWEEPER_DIR',  #
     '__version__'
 ]
 
-__version__ = "1.4.2"
+CREDSWEEPER_DIR = Path(__file__).resolve().parent
+
+__version__ = "1.4.4"
