@@ -1,16 +1,19 @@
+import binascii
 import logging
+import os
 import sys
 import time
 from argparse import ArgumentParser, ArgumentTypeError, Namespace
 from typing import Any, Union, Optional, Dict
 
-from credsweeper import __version__
+from credsweeper import __version__, CREDSWEEPER_DIR
 from credsweeper.app import CredSweeper
 from credsweeper.common.constants import ThresholdPreset
 from credsweeper.file_handler.files_provider import FilesProvider
 from credsweeper.file_handler.patch_provider import PatchProvider
 from credsweeper.file_handler.text_provider import TextProvider
 from credsweeper.logger.logger import Logger
+from credsweeper.utils import Util
 
 EXIT_SUCCESS = 0
 EXIT_FAILURE = 1
@@ -64,18 +67,61 @@ def logger_levels(log_level: str) -> str:
     raise ArgumentTypeError(f"log level given: {log_level} -- must be one of: {' | '.join(Logger.LEVELS.keys())}")
 
 
+def check_integrity() -> int:
+    """Calculates CRC32 of program files
+
+    Returns CRC32 of files in integer
+    """
+    crc32 = 0
+    for root, dirs, files in os.walk(str(CREDSWEEPER_DIR)):
+        for file_path in files:
+            if Util.get_extension(file_path) in [".py", ".json", ".txt", ".yaml", ".onnx"]:
+                with open(os.path.join(root, file_path), "rb") as f:
+                    crc32 ^= binascii.crc32(f.read())
+    return crc32
+
+
 def get_arguments() -> Namespace:
     """All CLI arguments are defined here"""
     parser = ArgumentParser(prog="python -m credsweeper")
     group = parser.add_mutually_exclusive_group(required=True)
     group.add_argument("--path", nargs="+", help="file or directory to scan", dest="path", metavar="PATH")
     group.add_argument("--diff_path", nargs="+", help="git diff file to scan", dest="diff_path", metavar="PATH")
+    group.add_argument("--export_config",
+                       nargs="?",
+                       help="exporting default config to file (default: config.json)",
+                       const="config.json",
+                       dest="export_config",
+                       metavar="PATH")
+    group.add_argument("--export_log_config",
+                       nargs="?",
+                       help="exporting default logger config to file (default: log.yaml)",
+                       const="log.yaml",
+                       dest="export_log_config",
+                       metavar="PATH")
     parser.add_argument("--rules",
                         nargs="?",
                         help="path of rule config file (default: credsweeper/rules/config.yaml)",
                         default=None,
                         dest="rule_path",
                         metavar="PATH")
+    parser.add_argument("--config",
+                        nargs="?",
+                        help="use custom config (default: built-in)",
+                        default=None,
+                        dest="config_path",
+                        metavar="PATH")
+    parser.add_argument("--log_config",
+                        nargs="?",
+                        help="use custom log config (default: built-in)",
+                        default=None,
+                        dest="log_config_path",
+                        metavar="PATH")
+    parser.add_argument("--denylist",
+                        help="path to a plain text file with lines or secrets to ignore",
+                        default=None,
+                        dest="denylist_path",
+                        metavar="PATH")
     parser.add_argument("--find-by-ext",
                         help="find files by predefined extension.",
                         dest="find_by_ext",
@@ -144,6 +190,10 @@ def get_arguments() -> Namespace:
                         help="set size limit of files that for scanning (eg. 1GB / 10MiB / 1000)",
                         dest="size_limit",
                         default=None)
+    parser.add_argument("--banner",
+                        help="show version and crc32 sum of CredSweeper files at start",
+                        action="store_const",
+                        const=True)
     parser.add_argument("--version",
                         "-V",
                         help="show program's version number and exit",
@@ -184,7 +234,13 @@ def scan(args: Namespace, content_provider: FilesProvider, json_filename: Option
 
     """
     try:
+        if args.denylist_path is not None:
+            denylist = [line for line in Util.read_file(args.denylist_path) if line]
+        else:
+            denylist = []
+
         credsweeper = CredSweeper(rule_path=args.rule_path,
+                                  config_path=args.config_path,
                                   api_validation=args.api_validation,
                                   json_filename=json_filename,
                                   xlsx_filename=xlsx_filename,
@@ -193,7 +249,9 @@ def scan(args: Namespace, content_provider: FilesProvider, json_filename: Option
                                   ml_threshold=args.ml_threshold,
                                   find_by_ext=args.find_by_ext,
                                   depth=args.depth,
-                                  size_limit=args.size_limit)
+                                  size_limit=args.size_limit,
+                                  exclude_lines=denylist,
+                                  exclude_values=denylist)
         return credsweeper.run(content_provider=content_provider)
     except Exception as exc:
         logger.critical(exc, exc_info=True)
@@ -205,7 +263,9 @@ def main() -> int:
     result = EXIT_FAILURE
     start_time = time.time()
     args = get_arguments()
-    Logger.init_logging(args.log)
+    if args.banner:
+        print(f"CredSweeper {__version__} crc32:{check_integrity():08x}")
+    Logger.init_logging(args.log, args.log_config_path)
     logger.info(f"Init CredSweeper object with arguments: {args}")
     summary: Dict[str, int] = {}
     if args.path:
@@ -229,6 +289,14 @@ def main() -> int:
         summary["Deleted File Credentials"] = del_credentials_number
         if 0 <= add_credentials_number and 0 <= del_credentials_number:
             result = EXIT_SUCCESS
+    elif args.export_config:
+        logging.info(f"Exporting default config to file: {args.export_config}")
+        config_dict = Util.json_load(os.path.join(CREDSWEEPER_DIR, "secret", "config.json"))
+        Util.json_dump(config_dict, args.export_config)
+    elif args.export_log_config:
+        logging.info(f"Exporting default logger config to file: {args.export_log_config}")
+        config_dict = Util.yaml_load(os.path.join(CREDSWEEPER_DIR, "secret", "log.yaml"))
+        Util.yaml_dump(config_dict, args.export_log_config)
     else:
         logger.error("Not specified 'path' or 'diff_path'")
 
