@@ -42,6 +42,7 @@ class CredSweeper:
 
     def __init__(self,
                  rule_path: Optional[str] = None,
+                 config_path: Optional[str] = None,
                  api_validation: bool = False,
                  json_filename: Optional[str] = None,
                  xlsx_filename: Optional[str] = None,
@@ -51,12 +52,16 @@ class CredSweeper:
                  ml_threshold: Union[float, ThresholdPreset] = ThresholdPreset.medium,
                  find_by_ext: bool = False,
                  depth: int = 0,
-                 size_limit: Optional[str] = None) -> None:
+                 size_limit: Optional[str] = None,
+                 exclude_lines: Optional[List[str]] = None,
+                 exclude_values: Optional[List[str]] = None) -> None:
         """Initialize Advanced credential scanner.
 
         Args:
             rule_path: optional str variable, path of rule config file
                 validation was the grained candidate model on machine learning
+            config_path: optional str variable, path of CredSweeper config file
+                default built-in config is used if None
             api_validation: optional boolean variable, specifying the need of
                 parallel API validation
             json_filename: optional string variable, path to save result
@@ -70,11 +75,16 @@ class CredSweeper:
             find_by_ext: boolean - files will be reported by extension
             depth: int - how deep container files will be scanned
             size_limit: optional string integer or human-readable format to skip oversize files
+            exclude_lines: lines to omit in scan. Will be added to the lines already in config
+            exclude_values: values to omit in scan. Will be added to the values already in config
 
         """
         self.pool_count: int = int(pool_count) if int(pool_count) > 1 else 1
-        dir_path = os.path.dirname(os.path.realpath(__file__))
-        config_dict = Util.json_load(os.path.join(dir_path, "secret", "config.json"))
+        if config_path:
+            config_dict = Util.json_load(config_path)
+        else:
+            dir_path = os.path.dirname(os.path.realpath(__file__))
+            config_dict = Util.json_load(os.path.join(dir_path, "secret", "config.json"))
 
         config_dict["validation"] = {}
         config_dict["validation"]["api_validation"] = api_validation
@@ -82,6 +92,10 @@ class CredSweeper:
         config_dict["find_by_ext"] = find_by_ext
         config_dict["size_limit"] = size_limit
         config_dict["depth"] = depth
+        if exclude_lines is not None:
+            config_dict["exclude"]["lines"] = config_dict["exclude"].get("lines", []) + exclude_lines
+        if exclude_values is not None:
+            config_dict["exclude"]["values"] = config_dict["exclude"].get("values", []) + exclude_values
 
         self.config = Config(config_dict)
         self.credential_manager = CredentialManager()
@@ -228,17 +242,21 @@ class CredSweeper:
 
         """
         candidates: List[Candidate] = []
-        logger.debug("Start scan file: %s", content_provider.file_path)
+        logger.debug("Start scan file: %s %s", content_provider.file_path, content_provider.info)
 
-        if FilePathExtractor.is_find_by_ext_file(self.config, content_provider.file_path):
+        if FilePathExtractor.is_find_by_ext_file(self.config, content_provider.file_type):
             # Skip the file scanning and create fake candidate because the extension is suspicious
-            candidates.append(Candidate.get_dummy_candidate(self.config, content_provider.file_path))
+            dummy_candidate = Candidate.get_dummy_candidate(self.config, content_provider.file_path,
+                                                            content_provider.file_type, content_provider.info)
+            candidates.append(dummy_candidate)
 
         elif self.config.depth > 0 and isinstance(content_provider, TextContentProvider):
             # Feature to scan files which might be containers
             data = Util.read_data(content_provider.file_path)
             if data:
-                data_provider = DataContentProvider(data=data, file_path=content_provider.file_path)
+                data_provider = DataContentProvider(data=data,
+                                                    file_path=content_provider.file_path,
+                                                    info=content_provider.file_path)
                 candidates = self.data_scan(data_provider, self.config.depth, RECURSIVE_SCAN_LIMITATION)
 
         else:
@@ -260,7 +278,8 @@ class CredSweeper:
                 recursive_limit_size: maximal bytes of opened files to prevent recursive zip-bomb attack
         """
         candidates: List[Candidate] = []
-        logger.debug("Start scan data: %s %d bytes", data_provider.file_path, len(data_provider.data))
+        logger.debug("Start data_scan: size=%d, depth=%d, limit=%d, path=%s, info=%s", len(data_provider.data), depth,
+                     recursive_limit_size, data_provider.file_path, data_provider.info)
 
         if 0 > depth:
             # break recursion if maximal depth is reached
@@ -269,30 +288,35 @@ class CredSweeper:
 
         depth -= 1
 
-        if FilePathExtractor.is_find_by_ext_file(self.config, data_provider.file_path):
+        if FilePathExtractor.is_find_by_ext_file(self.config, data_provider.file_type):
             # Skip scanning file and makes fake candidate due the extension is suspicious
-            candidates.append(Candidate.get_dummy_candidate(self.config, data_provider.file_path))
+            dummy_candidate = Candidate.get_dummy_candidate(self.config, data_provider.file_path,
+                                                            data_provider.file_type, data_provider.info)
+            candidates.append(dummy_candidate)
 
         elif Util.is_zip(data_provider.data):
             # detected zip signature
             try:
                 with zipfile.ZipFile(io.BytesIO(data_provider.data)) as zf:
                     for zfl in zf.infolist():
-                        file_path = f"{data_provider.file_path}/{zfl.filename}"
                         # skip directory
-                        if "/" == file_path[-1:]:
+                        if "/" == zfl.filename[-1:]:
                             continue
-                        if FilePathExtractor.check_exclude_file(self.config, file_path):
+                        if FilePathExtractor.check_exclude_file(self.config, zfl.filename):
                             continue
                         if 0 > recursive_limit_size - zfl.file_size:
-                            logger.error(
-                                f"{file_path}: size {zfl.file_size} is over limit {recursive_limit_size} depth:{depth}")
+                            logger.error(f"{zfl.filename}: size {zfl.file_size}"
+                                         f" is over limit {recursive_limit_size} depth:{depth}")
                             continue
                         with zf.open(zfl) as f:
-                            zip_content_provider = DataContentProvider(data=f.read(), file_path=file_path)
+                            zip_content_provider = DataContentProvider(data=f.read(),
+                                                                       file_path=data_provider.file_path,
+                                                                       file_type=Util.get_extension(zfl.filename),
+                                                                       info=f"{data_provider.info}|ZIP|{zfl.filename}")
                             # nevertheless use extracted data size
                             new_limit = recursive_limit_size - len(zip_content_provider.data)
-                            candidates.extend(self.data_scan(zip_content_provider, depth, new_limit))
+                            zip_candidates = self.data_scan(zip_content_provider, depth, new_limit)
+                            candidates.extend(zip_candidates)
 
             except Exception as zip_exc:
                 # too many exception types might be produced with broken zip
@@ -301,15 +325,23 @@ class CredSweeper:
         elif Util.is_gzip(data_provider.data):
             try:
                 with gzip.open(io.BytesIO(data_provider.data)) as f:
-                    gzip_content_provider = DataContentProvider(data=f.read(), file_path=data_provider.file_path)
+                    new_path = data_provider.file_path if ".gz" != Util.get_extension(
+                        data_provider.file_path) else data_provider.file_path[:-3]
+                    gzip_content_provider = DataContentProvider(data=f.read(),
+                                                                file_path=data_provider.file_path,
+                                                                file_type=Util.get_extension(new_path),
+                                                                info=f"{data_provider.info}|GZIP|{new_path}")
                     new_limit = recursive_limit_size - len(gzip_content_provider.data)
-                    candidates.extend(self.data_scan(gzip_content_provider, depth, new_limit))
+                    candidates = self.data_scan(gzip_content_provider, depth, new_limit)
             except Exception as gzip_exc:
                 logger.error(f"{data_provider.file_path}:{gzip_exc}")
 
         else:
-            # finally try scan the date via byte content provider
-            byte_content_provider = ByteContentProvider(content=data_provider.data, file_path=data_provider.file_path)
+            # finally try scan the data via byte content provider
+            byte_content_provider = ByteContentProvider(content=data_provider.data,
+                                                        file_path=data_provider.file_path,
+                                                        file_type=data_provider.file_type,
+                                                        info=f"{data_provider.info}|RAW")
             analysis_targets = byte_content_provider.get_analysis_target()
             candidates = self.scanner.scan(analysis_targets)
 
