@@ -98,18 +98,18 @@ class FilePathExtractor:
                 parent_directory = new_parent
 
     @staticmethod
-    def is_find_by_ext_file(config: Config, path: str) -> bool:
+    def is_find_by_ext_file(config: Config, extension: str) -> bool:
         """
         Checks whether file has suspicious extension
 
         Args:
             config: Config
-            path: str - may be only file name with extension
+            extension: str - may be only file name with extension
 
         Return:
             True when the feature is configured and the file extension matches
         """
-        return config.find_by_ext and Util.get_extension(path) in config.find_by_ext_list
+        return config.find_by_ext and extension in config.find_by_ext_list
 
     @classmethod
     def check_exclude_file(cls, config: Config, path: str) -> bool:
@@ -130,7 +130,10 @@ class FilePathExtractor:
             return True
         if any(exclude_path in path for exclude_path in config.exclude_paths):
             return True
-        if Util.get_extension(path) in config.exclude_extensions:
+        file_extension = Util.get_extension(path, lower=False)
+        if file_extension in config.exclude_extensions:
+            return True
+        if not config.depth and file_extension in config.exclude_containers:
             return True
         return False
 
