@@ -5,17 +5,19 @@ from credsweeper.filters import Filter
 
 
 class ValueLastWordCheck(Filter):
-    """Check that secret is not short value that ends with `:`"""
+    """Check that secret is not short value that ends with `:`."""
+
     NOT_ALLOWED_COLON_PATTERN = regex.compile(".*:$", flags=regex.IGNORECASE)
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
