@@ -6,7 +6,8 @@ from credsweeper.utils import Util
 
 
 class ValueUselessWordCheck(Filter):
-    """Check is candidate value contains sub-rows with operators (like ->)"""
+    """Check is candidate value contains sub-rows with operators (like ->)."""
+
     NOT_ALLOWED = [
         "((\\{)?(0x)+([0-9a-f]|\\%){1}.*)",  # Check is contain \{0x or 0x
         "(\\-\\>.*)",  # Check if contain ->
@@ -16,13 +17,14 @@ class ValueUselessWordCheck(Filter):
     NOT_ALLOWED_PATTERN = regex.compile(Util.get_regex_combine_or(NOT_ALLOWED), flags=regex.IGNORECASE)
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
