@@ -1,12 +1,12 @@
-from dataclasses import dataclass
-from typing import Dict, List, Tuple, Optional, Any
-
 import json
 import logging
 import math
 import os
-import whatthepatch
+from dataclasses import dataclass
+from typing import Dict, List, Tuple, Optional, Any
 
+import whatthepatch
+import yaml
 from lxml import etree
 from regex import regex
 from typing_extensions import TypedDict
@@ -41,10 +41,10 @@ class Util:
     default_encodings: Tuple[str, ...] = AVAILABLE_ENCODINGS
 
     @staticmethod
-    def get_extension(file_path: str) -> str:
-        """Return extension of file e.g.: '.txt'"""
-        _, extension = os.path.splitext(file_path)
-        return extension
+    def get_extension(file_path: str, lower=True) -> str:
+        """Return extension of file in lower case by default e.g.: '.txt', '.JPG'"""
+        _, extension = os.path.splitext(str(file_path))
+        return extension.lower() if lower else extension
 
     @staticmethod
     def get_keyword_pattern(keyword: str, separator: str = Separator.common) -> regex.Pattern:
@@ -338,3 +338,22 @@ class Util:
                 json.dump(obj, f, indent=indent)
         except Exception as exc:
             logging.error(f"Failed to write: {file_path} {exc}")
+
+    @staticmethod
+    def yaml_load(file_path: str, encoding=DEFAULT_ENCODING) -> Any:
+        """Load dictionary from yaml file"""
+        try:
+            with open(file_path, "r", encoding=encoding) as f:
+                return yaml.load(f, Loader=yaml.FullLoader)
+        except Exception as exc:
+            logger.error(f"Failed to read {file_path} {exc}")
+        return None
+
+    @staticmethod
+    def yaml_dump(obj: Any, file_path: str, encoding=DEFAULT_ENCODING) -> None:
+        """Write dictionary to yaml file"""
+        try:
+            with open(file_path, "w", encoding=encoding) as f:
+                yaml.dump(obj, f)
+        except Exception as exc:
+            logging.error(f"Failed to write: {file_path} {exc}")
